@@ -353,7 +353,7 @@ leaflet_map <-
 		url <- file.path(paths, filename)
 		url <- paste("file://",url,sep="")
 	}
-	url <- paste('http://mosaic-web.org/go/',filename,sep="")
+	url <- paste('http://www.mosaic-web.org/go/',filename,sep="")
 	if (is.null(position)) {
 		position <- data.frame(lat=latitude,lon=longitude)
 	}
@@ -392,7 +392,7 @@ leaflet_map <-
 #' 		url <- file.path(paths, filename)
 #' 		url <- paste("file://",url,sep="")
 #' 	}
-#' 	url <- paste('http://mosaic-web.org/go/',filename,sep="")
+#' 	url <- paste('http://www.mosaic-web.org/go/',filename,sep="")
 #' 	if (is.null(position)) {
 #' 		position <- data.frame(lat=latitude,lon=longitude)
 #' 	}
